/* 
 * Licensed to the soi-toolkit project under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The soi-toolkit project licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.soitoolkit.commons.mule.test;

/**
 * Adds the capability to run Mule unit tests with a servlet engine, i.e. testing services depending on the servlet-transport.
 * 
 * @author Magnus Larsson
 *
 */
public abstract class AbstractTestCaseWithServletEngine extends AbstractTestCase {

	private ServletContainerWithMuleReceiverServlet servletContainer = null;

	public AbstractTestCaseWithServletEngine(String muleServerId, int httpPort, String contextPath, String muleReceiverServletUri) {
		super();

		// Before launching Mule ESB set its server id
		System.setProperty("mule.serverId", muleServerId);
		
		servletContainer = new ServletContainerWithMuleReceiverServlet(httpPort, contextPath, muleReceiverServletUri);
    }

    @Override
    protected void doSetUp() throws Exception {
        super.doSetUp();
        servletContainer.start();
    }

    @Override
    protected void doTearDown() throws Exception {
    	servletContainer.shutdown();
        super.doTearDown();
    }

}
